package com.ruoyi.custclient.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.custclient.mapper.VehicleInfoMapper;
import com.ruoyi.custclient.domain.VehicleInfo;
import com.ruoyi.custclient.service.IVehicleInfoService;

/**
 * 用户车辆信息Service业务层处理
 * 
 * @author wuyufei
 * @date 2024-10-21
 */
@Service
public class VehicleInfoServiceImpl implements IVehicleInfoService 
{
    @Autowired
    private VehicleInfoMapper vehicleInfoMapper;

    /**
     * 查询用户车辆信息
     * 
     * @param id 用户车辆信息主键
     * @return 用户车辆信息
     */
    @Override
    public VehicleInfo selectVehicleInfoById(Long id)
    {
        return vehicleInfoMapper.selectVehicleInfoById(id);
    }

    /**
     * 查询用户车辆信息列表
     * 
     * @param vehicleInfo 用户车辆信息
     * @return 用户车辆信息
     */
    @Override
    public List<VehicleInfo> selectVehicleInfoList(VehicleInfo vehicleInfo)
    {
        return vehicleInfoMapper.selectVehicleInfoList(vehicleInfo);
    }

    /**
     * 新增用户车辆信息
     * 
     * @param vehicleInfo 用户车辆信息
     * @return 结果
     */
    @Override
    public int insertVehicleInfo(VehicleInfo vehicleInfo)
    {
        return vehicleInfoMapper.insertVehicleInfo(vehicleInfo);
    }

    /**
     * 修改用户车辆信息
     * 
     * @param vehicleInfo 用户车辆信息
     * @return 结果
     */
    @Override
    public int updateVehicleInfo(VehicleInfo vehicleInfo)
    {
        return vehicleInfoMapper.updateVehicleInfo(vehicleInfo);
    }

    /**
     * 批量删除用户车辆信息
     * 
     * @param ids 需要删除的用户车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteVehicleInfoByIds(Long[] ids)
    {
        return vehicleInfoMapper.deleteVehicleInfoByIds(ids);
    }

    /**
     * 删除用户车辆信息信息
     * 
     * @param id 用户车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteVehicleInfoById(Long id)
    {
        return vehicleInfoMapper.deleteVehicleInfoById(id);
    }
}
