package com.ruoyi.custclient.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.custclient.domain.VehicleInfo;
import com.ruoyi.custclient.service.IVehicleInfoService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 用户车辆信息Controller
 * 
 * @author wuyufei
 * @date 2024-10-21
 */
@RestController
@RequestMapping("/vehicleInfo")
public class VehicleInfoController extends BaseController
{
    @Autowired
    private IVehicleInfoService vehicleInfoService;

    /**
     * 查询用户车辆信息列表
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(VehicleInfo vehicleInfo)
    {
        startPage();
        List<VehicleInfo> list = vehicleInfoService.selectVehicleInfoList(vehicleInfo);
        return getDataTable(list);
    }

    /**
     * 导出用户车辆信息列表
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:export")
    @Log(title = "用户车辆信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VehicleInfo vehicleInfo)
    {
        List<VehicleInfo> list = vehicleInfoService.selectVehicleInfoList(vehicleInfo);
        ExcelUtil<VehicleInfo> util = new ExcelUtil<VehicleInfo>(VehicleInfo.class);
        util.exportExcel(response, list, "用户车辆信息数据");
    }

    /**
     * 获取用户车辆信息详细信息
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(vehicleInfoService.selectVehicleInfoById(id));
    }

    /**
     * 新增用户车辆信息
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:add")
    @Log(title = "用户车辆信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VehicleInfo vehicleInfo)
    {
        return toAjax(vehicleInfoService.insertVehicleInfo(vehicleInfo));
    }

    /**
     * 修改用户车辆信息
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:edit")
    @Log(title = "用户车辆信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VehicleInfo vehicleInfo)
    {
        return toAjax(vehicleInfoService.updateVehicleInfo(vehicleInfo));
    }

    /**
     * 删除用户车辆信息
     */
    @RequiresPermissions("vehicleInfo:vehicleInfo:remove")
    @Log(title = "用户车辆信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(vehicleInfoService.deleteVehicleInfoByIds(ids));
    }
}
